@@ -17,7 +17,7 @@ setMethod(
         else
             cat("FAILED TO CONVERGE within ", x@TOL, ' tolerance after ',
                 x@iter, ' ', method, " iterations.\n", sep="")
-        cat('mirt version:', as.character(packageVersion('mirt')), '\n')
+        cat('mirt version:', as.character(utils::packageVersion('mirt')), '\n')
         cat('M-step optimizer:', x@Moptim, '\n')
         cat('EM acceleration:', x@accelerate)
         cat('\nNumber of rectangular quadrature:', x@quadpts)
@@ -116,7 +116,11 @@ setMethod(
     f = "plot",
     signature = signature(x = 'DiscreteClass', y = 'missing'),
     definition = function(x, which.items = 1:ncol(x@Data$data),
-                          facet_items = TRUE, auto.key = TRUE, type = 'b', ...)
+                          facet_items = TRUE, type = 'b',
+                          par.strip.text = list(cex = 0.7),
+                          par.settings = list(strip.background = list(col = '#9ECAE1'),
+                                              strip.border = list(col = "black")),
+                          auto.key = list(space = 'right'), ...)
     {
         so <- summary(x)
         index <- which.items
@@ -131,14 +135,15 @@ setMethod(
             ret
         }, so=so, names=names)
         mlt <- do.call(rbind, mlt)
+        mlt$item <- factor(mlt$item, levels = colnames(x@Data$data)[which.items])
         if(facet_items){
             return(xyplot(prob ~ cat|item, data=mlt, groups = class, type = type,
                           auto.key = auto.key, ylab = 'Probability', ylim = c(-.1, 1.1),
-                          ...))
+                          par.settings=par.settings, par.strip.text=par.strip.text, ...))
         } else {
-            return(xyplot(prob ~ cat|class, data=mlt, groups = item, type = type,
-                          auto.key = auto.key, ylab = 'Probability', , ylim = c(-.1, 1.1),
-                          ...))
+            return(xyplot(prob ~ cat|class, data=mlt, groups = mlt$item, type = type,
+                          auto.key = auto.key, ylab = 'Probability', ylim = c(-.1, 1.1),
+                          par.settings=par.settings, par.strip.text=par.strip.text, ...))
         }
     }
 )
