@@ -87,7 +87,7 @@ M2 <- function(obj, calcNull = TRUE, quadpts = NULL, theta_lim = c(-6, 6),
         if(impute == 0)
             stop('Fit statistics cannot be computed when there are missing data. Pass a suitable
                  impute argument to compute statistics following multiple
-                 data inputations', call.=FALSE)
+                 data imputations', call.=FALSE)
         Theta <- fscores(obj, plausible.draws = impute)
         collect <- myLapply(Theta, fn, obj=obj, calcNull=calcNull,
                             quadpts=quadpts)
@@ -190,6 +190,9 @@ M2 <- function(obj, calcNull = TRUE, quadpts = NULL, theta_lim = c(-6, 6),
     pars <- obj@pars
     if(is.null(quadpts))
         quadpts <- select_quadpts(obj@nfact)
+    if(obj@nfact > 3L && !QMC)
+        warning('High-dimensional models should use quasi-Monte Carlo integration. Pass QMC=TRUE',
+                call.=FALSE)
     estpars <- c()
     for(i in 1L:(nitems+1L))
         estpars <- c(estpars, pars[[i]]@est)
