@@ -99,7 +99,7 @@ setMethod(
     {
         if(printSE) rawug <- TRUE
         if(CI >= 1 || CI <= 0)
-            stop('CI must be between 0 and 1')
+            stop('CI must be between 0 and 1', call.=FALSE)
         z <- abs(qnorm((1 - CI)/2))
         SEnames <- paste0('CI_', c((1 - CI)/2*100, ((1 - CI)/2 + CI)*100))
         K <- object@K
