@@ -65,18 +65,28 @@
 #'
 #' \dontrun{
 #'
+#' P <- function(Theta){exp(Theta^2 * 1.2 - 1) / (1 + exp(Theta^2 * 1.2 - 1))}
+#'
 #' #make some data
 #' set.seed(1234)
 #' a <- matrix(rlnorm(20, meanlog=0, sdlog = .1),ncol=1)
 #' d <- matrix(rnorm(20),ncol=1)
+#' Theta <- matrix(rnorm(2000))
 #' items <- rep('dich', 20)
-#' data <- simdata(a,d, 2000, items)
+#' ps <- P(Theta)
+#' baditem <- numeric(2000)
+#' for(i in 1:2000)
+#'    baditem[i] <- sample(c(0,1), 1, prob = c(1-ps[i], ps[i]))
+#' data <- cbind(simdata(a,d, 2000, items, Theta=Theta), baditem=baditem)
 #'
 #' x <- mirt(data, 1)
 #' raschfit <- mirt(data, 1, itemtype='Rasch')
 #' fit <- itemfit(x)
 #' fit
 #'
+#' fit <- itemfit(x, X2=TRUE)
+#' fit$X2
+#'
 #' itemfit(x, empirical.plot = 1) #empirical item plot
 #' itemfit(x, empirical.plot = 1, empirical.CI = .99) #empirical item plot with 99% CI's
 #'
@@ -113,17 +123,23 @@
 #' mirtCluster() # run in parallel
 #' itemfit(raschfit, impute = 10)
 #'
+#' #alternative route: use only valid data, and create a model with the previous parameter estimates
+#' data2 <- na.omit(data)
+#' raschfit2 <- mirt(data2, 1, itemtype = 'Rasch', pars=mod2values(raschfit), TOL=NaN)
+#' itemfit(raschfit2)
 #'   }
 #'
 itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, mincell = 1, S_X2.tables = FALSE,
                     empirical.plot = NULL, empirical.CI = 0, method = 'EAP', Theta = NULL,
                     impute = 0, digits = 4, ...){
 
-    fn <- function(Theta, obj, digits, ...){
-        tmpdat <- imputeMissing(obj, Theta)
-        tmpmod <- mirt(tmpdat, obj@nfact, pars = vals, itemtype = obj@itemtype)
+    fn <- function(ind, Theta, obj, vals, ...){
+        tmpdat <- imputeMissing(obj, Theta[[ind]])
+        tmpmod <- mirt(tmpdat, obj@nfact, pars = vals, itemtype = obj@itemtype,
+                       technical=list(customK=obj@K))
         tmpmod@pars <- obj@pars
-        return(itemfit(tmpmod, Theta=Theta, digits = 200, ...))
+        whc <- 1L:length(Theta)
+        return(itemfit(tmpmod, Theta=Theta[[sample(whc[-ind], 1L)]], digits = Inf, ...))
     }
 
     if(missing(x)) missingMsg('x')
@@ -135,21 +151,27 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
         discrete <- TRUE
     }
 
-    if((impute != 0 || any(is.na(x@Data$data))) && !is(x, 'MultipleGroupClass')){
+    stopifnot(Zh || X2 || S_X2)
+    if(any(is.na(x@Data$data)) && (Zh || S_X2) && impute == 0)
+        stop('Only X2 can be compute without imputed datsets', call.=FALSE)
+
+    if(impute != 0 && !is(x, 'MultipleGroupClass')){
         if(impute == 0)
             stop('Fit statistics cannot be computed when there are missing data. Pass a suitable
                  impute argument to compute statistics following multiple data
                  imputations', call.=FALSE)
+        if(sum(is.na(x@Data$data)) / length(x@Data$data) > .10)
+            warning('Imputations for large amounts of missing data may be overly conservative', call.=FALSE)
         stopifnot(impute > 1L)
         Theta <- fscores(x, plausible.draws = impute)
         collect <- vector('list', impute)
         vals <- mod2values(x)
         vals$est <- FALSE
-        collect <- myLapply(Theta, fn, obj=x, vals=vals,
+        collect <- myLapply(1L:impute, fn, Theta=Theta, obj=x, vals=vals,
                             Zh=Zh, X2=X2, group.size=group.size, mincell=mincell,
                             S_X2.tables=S_X2.tables, empirical.plot=empirical.plot,
                             empirical.CI=empirical.CI, method=method, impute=0,
-                            discrete=discrete, digits = 200, ...)
+                            discrete=discrete, ...)
         ave <- SD <- collect[[1L]]
         pick1 <- 1:nrow(ave)
         pick2 <- sapply(ave, is.numeric)
@@ -169,9 +191,13 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
     if(is(x, 'MultipleGroupClass')){
         ret <- vector('list', length(x@pars))
         if(is.null(Theta))
-            Theta <- fscores(x, method=method, full.scores=TRUE, ...)
+            Theta <- fscores(x, method=method, full.scores=TRUE, plausible.draws=impute, ...)
         for(g in 1L:length(x@pars)){
-            tmpTheta <- Theta[x@Data$groupNames[g] == x@Data$group, , drop=FALSE]
+            if(impute > 0L){
+                tmpTheta <- vector('list', impute)
+                for(i in 1L:length(tmpTheta))
+                    tmpTheta[[i]] <- Theta[[i]][x@Data$groupNames[g] == x@Data$group, , drop=FALSE]
+            } else tmpTheta <- Theta[x@Data$groupNames[g] == x@Data$group, , drop=FALSE]
             tmp_obj <- MGC2SC(x, g)
             ret[[g]] <- itemfit(tmp_obj, Zh=Zh, X2=X2, group.size=group.size, mincell=mincell,
                                 S_X2.tables=S_X2.tables, empirical.plot=empirical.plot,
@@ -189,7 +215,7 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
     J <- ncol(x@Data$data)
     itemloc <- x@itemloc
     pars <- x@pars
-    if(Zh || X2){
+    if(Zh){
         if(is.null(Theta))
             Theta <- fscores(x, verbose=FALSE, full.scores=TRUE, method=method, ...)
         prodlist <- attr(pars, 'prodlist')
@@ -246,9 +272,24 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
             }
         }
     }
-    if((X2 || !is.null(empirical.plot)) && nfact == 1L){
+    if((X2 || !is.null(empirical.plot)) && x@nfact == 1L){
+        if(is.null(Theta))
+            Theta <- fscores(x, verbose=FALSE, full.scores=TRUE, method=method, ...)
+        nfact <- ncol(Theta)
+        prodlist <- attr(pars, 'prodlist')
+        fulldata <- x@Data$fulldata[[1L]]
+        if(any(Theta %in% c(Inf, -Inf))){
+            for(i in 1L:ncol(Theta)){
+                tmp <- Theta[,i]
+                tmp[tmp %in% c(-Inf, Inf)] <- NA
+                Theta[Theta[,i] == Inf, i] <- max(tmp, na.rm=TRUE) + .1
+                Theta[Theta[,i] == -Inf, i] <- min(tmp, na.rm=TRUE) - .1
+            }
+        }
         ord <- order(Theta[,1L])
         fulldata <- fulldata[ord,]
+        pick <- !is.na(x@Data$data)
+        pick <- pick[ord, ]
         Theta <- Theta[ord, , drop = FALSE]
         den <- dnorm(Theta, 0, .5)
         den <- den / sum(den)
@@ -275,10 +316,10 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
         for (i in 1L:J){
             if(!is.null(empirical.plot) && i != empirical.plot) next
             for(j in unique(Groups)){
-                dat <- fulldata[Groups == j, itemloc[i]:(itemloc[i+1] - 1), drop = FALSE]
+                dat <- fulldata[Groups == j & pick[,i], itemloc[i]:(itemloc[i+1] - 1), drop = FALSE]
                 r <- colSums(dat)
                 N <- nrow(dat)
-                mtheta <- matrix(mean(Theta[Groups == j,]), nrow=1)
+                mtheta <- matrix(mean(Theta[Groups == j & pick[,i],]), nrow=1)
                 if(!is.null(empirical.plot)){
                     tmp <- r/N
                     empirical.plot_points[j, ] <- c(mtheta, N, tmp)
@@ -316,7 +357,7 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
             plt.2 <- reshape(plt.2, varying = 3:ncol(plt.2), direction = 'long', timevar = 'cat')
             plt <- cbind(plt.1, plt.2)
             if(K == 2) plt <- plt[plt$cat != 1, ]
-            return(xyplot(P ~ Theta, plt, group = cat,
+            return(xyplot(P ~ Theta, plt, groups = cat,
                           main = paste('Empirical plot for item', empirical.plot),
                             ylim = c(-0.1,1.1), xlab = expression(theta), ylab=expression(P(theta)),
                           auto.key=ifelse(K==2, FALSE, TRUE), EPCI.lower=EPCI.lower,
@@ -350,6 +391,9 @@ itemfit <- function(x, Zh = TRUE, X2 = FALSE, S_X2 = TRUE, group.size = 150, min
         quadpts <- dots$quadpts
         if(is.null(quadpts) && QMC) quadpts <- 15000L
         if(is.null(quadpts)) quadpts <- select_quadpts(x@nfact)
+        if(x@nfact > 3L && !QMC)
+            warning('High-dimensional models should use quasi-Monte Carlo integration. Pass QMC=TRUE',
+                    call.=FALSE)
         theta_lim <- dots$theta_lim
         if(is.null(theta_lim)) theta_lim <- c(-6,6)
         gp <- ExtractGroupPars(pars[[length(pars)]])
