@@ -29,34 +29,39 @@ prodterms <- function(theta0, prodlist)
 draw.thetas <- function(theta0, pars, fulldata, itemloc, cand.t.var, prior.t.var,
                         prior.mu, prodlist, OffTerm, CUSTOM.IND)
 {
-    N <- nrow(fulldata)
-    J <- length(pars) - 1L
-    unif <- runif(N)
-    sigma <- if(ncol(theta0) == 1L) matrix(cand.t.var) else diag(rep(cand.t.var,ncol(theta0)))
-    total_0 <- attr(theta0, 'log.lik_full')
-    theta1 <- theta0 + mirt_rmvnorm(N, sigma = sigma)
-    if(is.null(total_0)) theta1 <- theta0 #for intial draw
-    log_den1 <- mirt_dmvnorm(theta1,prior.mu,prior.t.var,log=TRUE)
-    if(length(prodlist) > 0L)
-        theta1 <- prodterms(theta1,prodlist)
-    itemtrace1 <- computeItemtrace(pars=pars, Theta=theta1, itemloc=itemloc,
-                                   offterm=OffTerm, CUSTOM.IND=CUSTOM.IND)
-    total_1 <- rowSums(fulldata * log(itemtrace1)) + log_den1
-    if(!is.null(prodlist))
-        theta1 <- theta1[ ,1L:(pars[[1L]]@nfact - pars[[1L]]@nfixedeffects -
-                                   length(prodlist)), drop=FALSE]
-    if(is.null(total_0)){ #for intial draw
+    makedraws <- try({
+        N <- nrow(fulldata)
+        J <- length(pars) - 1L
+        unif <- runif(N)
+        sigma <- if(ncol(theta0) == 1L) matrix(cand.t.var) else diag(rep(cand.t.var,ncol(theta0)))
+        total_0 <- attr(theta0, 'log.lik_full')
+        theta1 <- theta0 + mirt_rmvnorm(N, sigma = sigma)
+        if(is.null(total_0)) theta1 <- theta0 #for intial draw
+        log_den1 <- mirt_dmvnorm(theta1,prior.mu,prior.t.var,log=TRUE)
+        if(length(prodlist) > 0L)
+            theta1 <- prodterms(theta1,prodlist)
+        itemtrace1 <- computeItemtrace(pars=pars, Theta=theta1, itemloc=itemloc,
+                                       offterm=OffTerm, CUSTOM.IND=CUSTOM.IND)
+        total_1 <- rowSums(fulldata * log(itemtrace1)) + log_den1
+        if(!is.null(prodlist))
+            theta1 <- theta1[ ,1L:(pars[[1L]]@nfact - pars[[1L]]@nfixedeffects -
+                                       length(prodlist)), drop=FALSE]
+        if(is.null(total_0)){ #for intial draw
+            attr(theta1, 'log.lik_full') <- total_1
+            return(theta1)
+        }
+        diff <- total_1 - total_0
+        accept <- unif < exp(diff)
+        theta1[!accept, ] <- theta0[!accept, ]
+        total_1[!accept] <- total_0[!accept]
+        log.lik <- sum(total_1)
+        attr(theta1, "Proportion Accepted") <- sum(accept)/N
+        attr(theta1, "log.lik") <- log.lik
         attr(theta1, 'log.lik_full') <- total_1
-        return(theta1)
-    }
-    diff <- total_1 - total_0
-    accept <- unif < exp(diff)
-    theta1[!accept, ] <- theta0[!accept, ]
-    total_1[!accept] <- total_0[!accept]
-    log.lik <- sum(total_1)
-    attr(theta1, "Proportion Accepted") <- sum(accept)/N
-    attr(theta1, "log.lik") <- log.lik
-    attr(theta1, 'log.lik_full') <- total_1
+    }, silent = TRUE)
+    if(is(makedraws, 'try-error'))
+        stop('MH sampler failed. Model is likely unstable or may need better starting values',
+             .call=FALSE)
     return(theta1)
 }
 
@@ -596,8 +601,8 @@ UpdateConstrain <- function(pars, constrain, invariance, nfact, nLambdas, J, ngr
             for(i in 1L:length(redun)){
                 for(j in 1L:length(redun)){
                     if(j < i){
-                        if(all(constrain[[i]] %in% constrain[[j]] ||
-                                all(constrain[[j]] %in% constrain[[i]]))){
+                        if(all(constrain[[i]] %in% constrain[[j]]) ||
+                                all(constrain[[j]] %in% constrain[[i]])){
                             if(length(constrain[[i]]) < length(constrain[[j]])) redun[i] <- TRUE
                             else redun[j] <- TRUE
                         }
@@ -610,7 +615,7 @@ UpdateConstrain <- function(pars, constrain, invariance, nfact, nLambdas, J, ngr
     return(constrain)
 }
 
-UpdatePrior <- function(PrepList, model, groupNames){
+UpdatePrior <- function(PrepList, model, groupNames, warn = TRUE){
     if(!is.numeric(model[[1L]])){
         if(!length(model[[1L]]$x[model[[1L]]$x[,1L] == 'PRIOR', 2L])) return(PrepList)
         groupNames <- as.character(groupNames)
@@ -699,6 +704,15 @@ UpdatePrior <- function(PrepList, model, groupNames){
         }
         for(g in 1L:length(PrepList))
             PrepList[[g]]$pars <- pars[[g]]
+    } else {
+        if(warn){
+            speak <- PrepList[[1L]]$itemtype %in% c('3PL', '3PLu', '4PL', 'PC3PL', '3PLNRM', '3PLuNRM', '4PLNRM')
+            if(any(speak) && nrow(PrepList[[1L]]$fulldata) < 5000L)
+                warning(paste0('The following itemtypes are very unstable in smaller sample sizes:',
+                               unique(PrepList[[1]]$itemtype[speak]),
+                               '\nIncluding prior distributions for unstable parameters is recommended. '),
+                               call.=FALSE)
+        }
     }
     return(PrepList)
 }
@@ -916,9 +930,6 @@ ItemInfo <- function(x, Theta, cosangle, total.info = TRUE){
     dx <- DerivTheta(x, Theta)
     info <- matrix(0, nrow(Theta), ncol(P))
     cosanglefull <- matrix(cosangle, nrow(P), length(cosangle), byrow = TRUE)
-    if(ncol(cosanglefull) < ncol(dx$grad[[1L]]))
-        cosanglefull <- cbind(cosanglefull, matrix(1, nrow(cosanglefull),
-                                                   ncol(dx$grad[[1L]]) - ncol(cosanglefull)))
     for(i in 1L:x@ncat)
         dx$grad[[i]] <- matrix(rowSums(dx$grad[[i]] * cosanglefull))
     for(i in 1L:x@ncat)
@@ -1031,7 +1042,7 @@ updateGrad <- function(g, L) L %*% g
 updateHess <- function(h, L) L %*% h %*% L
 
 makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NULL,
-                     SE = FALSE, verbose = TRUE,
+                     SE = FALSE, verbose = TRUE, GenRandomPars,
                      SEtol = .001, grsm.block = NULL, D = 1, TOL = NULL,
                      rsm.block = NULL, calcNull = TRUE, BFACTOR = FALSE,
                      technical = list(), use = 'pairwise.complete.obs',
@@ -1042,7 +1053,7 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
     tnames <- names(technical)
     gnames <- c('MAXQUAD', 'NCYCLES', 'BURNIN', 'SEMCYCLES', 'set.seed', 'SEtol', 'symmetric_SEM',
                 'gain', 'warn', 'message', 'customK', 'customPriorFun', 'customTheta', 'MHcand',
-                'parallel', 'NULL.MODEL', 'theta_lim')
+                'parallel', 'NULL.MODEL', 'theta_lim', 'RANDSTART', 'MHDRAWS')
     if(!all(tnames %in% gnames))
         stop('The following inputs to technical are invalid: ',
              paste0(tnames[!(tnames %in% gnames)], ' '), call.=FALSE)
@@ -1085,8 +1096,9 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
     if(opts$method %in% c('EM', 'QMCEM'))
         opts$NCYCLES <- ifelse(is.null(technical$NCYCLES), 500L, technical$NCYCLES)
     opts$BURNIN <- ifelse(is.null(technical$BURNIN), 150L, technical$BURNIN)
-    opts$SEMCYCLES <- ifelse(is.null(technical$SEMCYCLES), 50, technical$SEMCYCLES)
+    opts$SEMCYCLES <- ifelse(is.null(technical$SEMCYCLES), 100L, technical$SEMCYCLES)
     opts$KDRAWS  <- ifelse(is.null(technical$KDRAWS), 1L, technical$KDRAWS)
+    opts$MHDRAWS  <- ifelse(is.null(technical$MHDRAWS), 5L, technical$MHDRAWS)
     opts$empiricalhist <- empiricalhist
     if(empiricalhist){
         if(opts$method != 'EM')
@@ -1098,10 +1110,10 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
     if(is.null(opts$theta_lim)) opts$theta_lim <- c(-6,6)
     if(method == 'QMCEM' && is.null(opts$quadpts)) opts$quadpts <- 5000L
     opts$MSTEPTOL <- ifelse(is.null(technical$MSTEPTOL), opts$TOL/1000, technical$MSTEPTOL)
-    if(opts$method == 'MHRM' || opts$method =='MIXED' || SE.type == 'MHRM')
+    if((opts$method == 'MHRM' || opts$method =='MIXED' || SE.type == 'MHRM') && !GenRandomPars)
         set.seed(12345L)
     if(!is.null(technical$set.seed)) set.seed(technical$set.seed)
-    opts$gain <- c(0.15,0.65)
+    opts$gain <- c(0.1, 0.75)
     if(!is.null(technical$gain)){
         if(length(technical$gain) == 2L && is.numeric(technical$gain))
             opts$gain <- technical$gain
@@ -1210,6 +1222,10 @@ make.randomdesign <- function(random, longdata, covnames, itemdesign, N){
     for(i in 1L:length(random)){
         f <- gsub(" ", "", as.character(random[[i]])[2L])
         splt <- strsplit(f, '\\|')[[1L]]
+        if(any(grepl('\\*', splt[2L]) | grepl('\\+', splt[2L])))
+            stop('The + and * operators are not supported. Please specify
+                 which effects you want to interact with the : operator, and specify
+                 additional random effects in seperate list elements', call.=FALSE)
         gframe <- model.frame(as.formula(paste0('~',splt[2L])), longdata)
         sframe <- model.frame(as.formula(paste0('~',splt[1L])), longdata)
         levels <- interaction(gframe)
@@ -1275,8 +1291,10 @@ make.lrdesign <- function(df, formula, factorNames, EM=FALSE){
         X <- model.matrix(formula, df)
     }
     tXX <- t(X) %*% X
-    if(ncol(X) > 1) inv_tXX <- solve(tXX)
+    if(ncol(X) > 1L) inv_tXX <- try(solve(tXX), silent = TRUE)
     else inv_tXX <- matrix(0)
+    if(is(inv_tXX, 'try-error'))
+        stop('Latent regression design matrix contains multicollinear terms.', call. = FALSE)
     beta <- matrix(0, ncol(X), nfact)
     sigma <- matrix(0, nfact, nfact)
     diag(sigma) <- 1
@@ -1288,7 +1306,7 @@ make.lrdesign <- function(df, formula, factorNames, EM=FALSE){
             est[colnames(X) %in% estnames[[i]], pick] <- TRUE
         }
     } else est <- matrix(TRUE, nrow(beta), ncol(beta))
-    est[1,] <- FALSE
+    est[1L, ] <- FALSE
     est <- as.logical(est)
     names(est) <- as.character(t(outer(factorNames, colnames(X),
                                      FUN = function(X, Y) paste(X,Y,sep="_"))))
@@ -1318,6 +1336,21 @@ make.lrdesign <- function(df, formula, factorNames, EM=FALSE){
     ret
 }
 
+update.lrPars <- function(df, lrPars){
+    pick <- df$class == 'lrPars'
+    df2 <- df[pick, , drop=FALSE]
+    lrPars@est[] <- df2$est
+    lrPars@par <- df2$value
+    if(!all(df2$lbound == -Inf))
+        warning('latent regression parameters cannot be bounded. Ignoring constraint', call.=FALSE)
+    if(!all(df2$ubound == Inf))
+        warning('latent regression parameters cannot be bounded. Ignoring constraint', call.=FALSE)
+    if(!all(df2$prior.type == 'none'))
+        warning('latent regression parameters do not support prior distribution. Ignoring input.',
+                call.=FALSE)
+    lrPars
+}
+
 
 OffTerm <- function(random, J, N){
     ret <- numeric(N*J)
