@@ -47,6 +47,318 @@ static void add2hess(NumericMatrix &out, const NumericMatrix &in, const double &
             out(i,j) = out(i,j) + in(i,j) * r;
 }
 
+static void matrixMult(vector<double> &c, const vector<double> &a, const vector<double> &b,
+                       const int *dim)
+{
+    NumericMatrix A(*dim, *dim), B(*dim, *dim), C(*dim, *dim);
+    int k = 0;
+
+    for (int j = 0; j < *dim; ++j){
+        for (int i = 0; i < *dim; ++i){
+            A(i,j) = a[k];
+            ++k;
+        }
+    }
+    k = 0;
+    for (int j = 0; j < *dim; ++j){
+        for (int i = 0; i < *dim; ++i){
+            B(i,j) = b[k];
+            ++k;
+        }
+    }
+    for (int i = 0; i < *dim; ++i){
+        for (int j = 0; j < *dim; ++j) {
+            C(i,j) = 0;
+            for (k = 0; k < *dim; ++k)
+                C(i,j) += A(i,k) * B(k,j);
+        }
+    }
+    k = 0;
+    for (int j = 0; j < *dim; ++j) {
+        for (int i = 0; i < *dim; ++i){
+            c[k] = C(i,j);
+            ++k;
+        }
+    }
+}
+
+static void matrixMult4(vector<double> &e, const vector<double> &a, const vector<double> &b,
+                        const vector<double> &c, const vector<double> &d, const int *dim)
+{
+    vector<double> tmp1(*dim * (*dim)), tmp2(*dim * (*dim));
+    matrixMult(tmp1, a, b, dim);
+    matrixMult(tmp2, tmp1, c, dim);
+    matrixMult(e, tmp2, d, dim);
+}
+
+
+static double tr(vector<double> &a, const int *dim)
+{
+    double trace = 0.0;
+    int k = 0;
+
+    for(int j = 0; j < *dim; ++j){
+        for(int i = 0; i < *dim; ++i){
+            if(i == j)
+                trace += a[k];
+            ++k;
+        }
+    }
+    return trace;
+}
+
+static void matrixSub(vector<double> &c, const vector<double> &a, const vector<double> &b,
+                      const int *dim)
+{
+    for(int i = 0; i < *dim*(*dim); ++i)
+        c[i] = a[i] - b[i];
+}
+
+static void outer(vector<double> &c, const vector<double> &a, const vector<double> &b,
+                  const int *dim)
+{
+    int k = 0;
+    for(int i = 0; i < *dim; ++i){
+        for(int j = 0; j < *dim; ++j){
+            c[k] = a[j] * b[i];
+            ++k;
+        }
+    }
+}
+
+static double inner(vector<double> &a, const vector<double> &b, const vector<double> &c,
+                    const int *dim)
+{
+    int k = 0;
+    NumericMatrix B(*dim, *dim);
+    double ret = 0.0;
+    vector<double> tmp(*dim);
+
+    for(int i = 0; i < *dim; ++i){
+        tmp[i] = 0.0;
+        for(int j = 0; j < *dim; ++j){
+            B(j,i) = b[k];
+            ++k;
+        }
+    }
+    for(int i = 0; i < *dim; ++i){
+        for(int j = 0; j < *dim; ++j){
+            tmp[i] += a[j] * B(j,i);
+            ++k;
+        }
+    }
+    for(int i = 0; i < *dim; ++i)
+        ret += tmp[i] * c[i];
+    return ret;
+}
+
+static void symMat(vector<double> &dsig, const int *nfact)
+{
+    int k = 0;
+    NumericMatrix tmp(*nfact, *nfact);
+
+    for(int i = 0; i < *nfact; ++i){
+        for(int j = 0; j < *nfact; ++j){
+            tmp(i,j) = dsig[k];
+            ++k;
+        }
+    }
+    for(int i = 0; i < *nfact; ++i)
+        for(int j = 0; j < *nfact; ++j)
+            if(i < j)
+                tmp(j,i) = tmp(i,j);
+    k = 0;
+    for(int i = 0; i < *nfact; ++i){
+        for(int j = 0; j < *nfact; ++j){
+            dsig[k] = tmp(i,j);
+            ++k;
+        }
+    }
+}
+
+static void _dgroup(vector<double> &grad, NumericMatrix &hess, const NumericMatrix &Theta,
+                    const arma::mat &Sig, const arma::mat &invSig, const arma::vec &meanTheta,
+                    const arma::vec &mu, const bool &estHess){
+    const int N = Theta.nrow();
+    const int nfact = Theta.ncol();
+    const int npars = nfact + nfact * (nfact + 1);
+    const int nsig = npars - nfact;
+
+    arma::mat Dif(N, nfact);
+    for (int j = 0; j < nfact; ++j)
+        for (int i = 0; i < N; ++i)
+            Dif(i,j) = Theta(i,j) - mu(j);
+    arma::mat Z = trans(Dif) * Dif;
+    arma::vec cMeans = N * (meanTheta - mu);
+    arma::vec g1 = invSig * cMeans;
+    arma::mat Zdif = Z - (N * Sig);
+    arma::mat tmp = invSig * Zdif * invSig;
+    for (int j = 0; j < nfact; ++j) tmp(j,j) = tmp(j,j)/2;
+    int ind = nfact;
+    for (int i = 0; i < nfact; ++i){
+        grad[i] = g1(i);
+        for (int j = 0; j < nfact; ++j){
+            if(i <= j){
+                grad[ind] = tmp(i,j);
+                ++ind;
+            }
+        }
+    }
+    if(estHess){
+        arma::mat hess2(npars, npars);
+        vector<double> invSig2(invSig.begin(), invSig.end());
+        const vector<double> cMeans2(cMeans.begin(), cMeans.end());
+        const vector<double> Zdif2(Zdif.begin(), Zdif.end());
+        vector<double> derv1(npars), derv2(npars), du1(nfact), du2(nfact), dsig1(nsig),
+            dsig2(nsig), dZ(nsig), dinvSig2(nsig), tmpmat(nsig), dZdif(nsig), Ndsig2(nsig);
+        double s1, s2, s3, s4, s5;
+
+        for(int j = 0; j < npars; ++j){
+            for(int i = 0; i < npars; ++i){
+                if(i <= j){
+                    for(int k = 0; k < npars; ++k){
+                        derv1[k] = 0.0;
+                        derv2[k] = 0.0;
+                    }
+                    derv1[i] = 1.0;
+                    derv2[j] = 1.0;
+                    for(int k = 0; k < nfact; ++k){
+                        du1[k] = derv1[k];
+                        du2[k] = derv2[k];
+                    }
+                    for(int k = nfact; k < npars; ++k){
+                        dsig1[k-nfact] = derv1[k];
+                        dsig2[k-nfact] = derv2[k];
+                    }
+                    symMat(dsig1, &nfact);
+                    symMat(dsig2, &nfact);
+                    matrixMult(tmpmat, invSig2, dsig2, &nfact);
+                    matrixMult(dinvSig2, tmpmat, invSig2, &nfact);
+                    for(int k = 0; k < nsig; ++k)
+                        dinvSig2[k] = -1.0 * dinvSig2[k];
+                    outer(dZ, cMeans2, du2, &nfact);
+                    for(int k = 0; k < nsig; ++k)
+                        Ndsig2[k] = N * dsig2[k];
+                    matrixSub(dZdif, dZ, Ndsig2, &nfact);
+                    matrixMult4(tmpmat, dsig1, dinvSig2, Zdif2, invSig2, &nfact);
+                    s1 = 0.5 * tr(tmpmat, &nfact);
+                    matrixMult4(tmpmat, dsig1, invSig2, Zdif2, dinvSig2, &nfact);
+                    s2 = 0.5 * tr(tmpmat, &nfact);
+                    matrixMult4(tmpmat, dsig1, invSig2, dZdif, invSig2, &nfact);
+                    s3 = 0.5 * tr(tmpmat, &nfact);
+                    s4 = inner(du1, dinvSig2, cMeans2, &nfact);
+                    s5 = N * inner(du1, invSig2, du2, &nfact);
+                    hess2(i,j) = s1 + s2 + s3 + s4 - s5;
+                    hess2(j,i) = hess2(i,j);
+                }
+            }
+        }
+        arma::uvec pick(nfact + nfact * (nfact + 1) / 2);
+        ind = 0;
+        int whichrow = nfact;
+        for(int  i = 0; i < nfact; ++i){
+            pick(i) = ind;
+            ++ind;
+        }
+        for(int  i = 0; i < nfact; ++i){
+            for(int  j = 0; j < nfact; ++j){
+                if(i <= j){
+                    pick(ind) = whichrow;
+                    ++ind;
+                }
+                ++whichrow;
+            }
+        }
+        arma::mat newh = hess2.submat(pick, pick);
+        const int n_cols = newh.n_cols;
+        for (int i = 0; i < n_cols; ++i)
+            for (int j = 0; j < n_cols; ++j)
+                hess(i,j) = newh(i,j);
+    }
+}
+
+static void _dgroup_pre(vector<double> &grad, NumericMatrix &hess, S4 &obj,
+                        const NumericMatrix &Theta, const bool &estHess){
+    NumericMatrix sig = obj.slot("sig");
+    const int nfact = sig.ncol();
+    NumericMatrix invsig = obj.slot("invsig");
+    NumericVector MU = obj.slot("mu");
+    NumericVector MeanTheta = obj.slot("meanTheta");
+    arma::mat Sig(sig.begin(), nfact, nfact, false);
+    arma::mat invSig(invsig.begin(), nfact, nfact, false);
+    arma::vec mu(MU.begin(), nfact, false);
+    arma::vec meanTheta(MeanTheta.begin(), nfact, false);
+    NumericMatrix rs = obj.slot("dat");
+    const int grad_size = grad.size();
+    vector<double> g(grad_size);
+    NumericMatrix h(grad_size, grad_size);
+    NumericMatrix theta(1, Theta.ncol());
+    for(int i = 0; i < Theta.nrow(); ++i){
+        for(int j = 0; j < Theta.ncol(); ++j)
+            theta(0,j) = Theta(i,j);
+        _dgroup(g, h, theta, Sig, invSig, meanTheta, mu, estHess);
+        for(int j = 0; j < grad_size; ++j)
+            for(int k = 0; k < rs.ncol(); ++k)
+                grad[j] += rs(i, k) * g[j];
+    }
+}
+
+RcppExport SEXP dgroup(SEXP Robj, SEXP RTheta, SEXP RestHess, SEXP Rrandeff)
+{
+    S4 obj(Robj);
+    NumericMatrix Theta(RTheta);
+    const bool estHess = as<bool>(RestHess);
+    const bool randeff = as<bool>(Rrandeff);
+    const int nfact = Theta.ncol();
+    const int N = Theta.nrow();
+    NumericVector par = obj.slot("par");
+    arma::vec mu(nfact);
+    arma::mat Sig(nfact, nfact);
+    int ind;
+    if(randeff){
+        ind = 0;
+        for (int i = 0; i < nfact; ++i){
+            for (int j = 0; j < nfact; ++j){
+                if(i <= j){
+                    Sig(i,j) = par(ind);
+                    Sig(j,i) = Sig(i,j);
+                    ++ind;
+                }
+            }
+        }
+    } else {
+        for (int i = 0; i < nfact; ++i) mu(i) = par(i);
+        ind = nfact;
+        for (int i = 0; i < nfact; ++i){
+            for (int j = 0; j < nfact; ++j){
+                if(i <= j){
+                    Sig(i,j) = par(ind);
+                    Sig(j,i) = Sig(i,j);
+                    ++ind;
+                }
+            }
+        }
+    }
+    const int npars2 = nfact + nfact * (nfact + 1) / 2;
+    arma::mat invSig = inv(Sig);
+    arma::vec meanTheta(nfact);
+    for (int j = 0; j < nfact; ++j){
+        double tmp = 0.0;
+        for (int i = 0; i < N; ++i)
+            tmp += Theta(i,j) / N;
+        meanTheta(j) = tmp;
+    }
+    vector<double> grad(npars2);
+    NumericMatrix hess(npars2, npars2);
+    _dgroup(grad, hess, Theta, Sig, invSig, meanTheta, mu, estHess);
+
+    List ret;
+    ret["grad"] = wrap(grad);
+    ret["hess"] = hess;
+
+    return(ret);
+}
+
 static void d_nominal(vector<double> &grad, NumericMatrix &hess, const vector<double> &par,
     const NumericMatrix &Theta, const NumericVector &ot, const NumericMatrix &dat,
     const int &N, const int &nfact, const int &ncat, const int &israting, const int &estHess)
@@ -261,7 +573,7 @@ static void d_nominal2(vector<double> &grad, NumericMatrix &hess, const vector<d
     for(int i = 0; i < N; ++i){
         double tmp = 0.0;
         for(int j = 0; j < ncat; ++j){
-            tmp += num(i, j); 
+            tmp += num(i, j);
             // P2(i,j) = P(i,j) * P(i,j);
         }
         Q[i] = 1.0 / tmp;
@@ -280,7 +592,7 @@ static void d_nominal2(vector<double> &grad, NumericMatrix &hess, const vector<d
     for(int i = 0; i < ncat; ++i)
         d[i] = par[i + nfact + ncat*nfact];
 
-    vector<double> offterm2(N), unitNvec(N, 1.0); 
+    vector<double> offterm2(N), unitNvec(N, 1.0);
     NumericMatrix NumSum(N,nfact);
     for(int i = 0; i < N; ++i){
         for(int j = 0; j < nfact; ++j){
@@ -296,7 +608,7 @@ static void d_nominal2(vector<double> &grad, NumericMatrix &hess, const vector<d
     for(int j = 0; j < nfact; ++j){
         double tmp = 0.0;
         for(int k = 0; k < ncat; ++k){
-            for(int i = 0; i < N; ++i)        
+            for(int i = 0; i < N; ++i)
                 tmp += dat(i,k) * (ak(k,j) * Theta(i,j) - Q[i] * NumSum(i,j));
         }
         grad[ind] = tmp;
@@ -311,7 +623,7 @@ static void d_nominal2(vector<double> &grad, NumericMatrix &hess, const vector<d
         grad[ind] = tmp;
         ++ind;
     }
-    
+
 
     // //hess
     // //a's
@@ -632,7 +944,7 @@ void d_lca(vector<double> &grad, NumericMatrix &hess, const vector<double> &par,
     vector<double> p(N*ncat);
     P_lca(p, par, score, Theta, N, ncat, nfact, 0);
     const NumericMatrix P = vec2mat(p, N, ncat);
-    
+
     for (int i = 0; i < N; ++i){
         int ind = 0;
         for (int k = 1; k < ncat; ++k){
@@ -849,12 +1161,17 @@ static void _computeDpars(vector<double> &grad, NumericMatrix &hess, const List
         vector<double> tmpgrad(par_size);
         NumericMatrix tmphess(par_size, par_size);
         int itemclass = as<int>(item.slot("itemclass"));
-        int ncat = as<int>(item.slot("ncat"));
+        int ncat;
+        if(itemclass != 0)
+            ncat = as<int>(item.slot("ncat"));
         vector<int> prior_type = as< vector<int> >(item.slot("prior.type"));
         vector<double> prior_1 = as< vector<double> >(item.slot("prior_1"));
         vector<double> prior_2 = as< vector<double> >(item.slot("prior_2"));
         NumericMatrix dat = item.slot("dat");
         switch(itemclass){
+            case 0 :
+                _dgroup_pre(tmpgrad, tmphess, item, theta, estHess);
+                break;
             case 1 :
                 d_dich(tmpgrad, tmphess, par, theta, offterm(_,i), dat, N, nfact2, estHess);
                 break;
@@ -960,7 +1277,7 @@ RcppExport SEXP computeInfo(SEXP Rpars, SEXP RTheta, SEXP RgPrior, SEXP Rprior,
             vector<double> Prior = as< vector<double> >(tmpvec);
             vector<double> expected(1), r1vec(N*J), r2vec(N);
             if(isbifactor){
-               _Estepbfactor(expected, r1vec, r2vec, itemtrace, prior, Priorbetween, vone, 
+               _Estepbfactor(expected, r1vec, r2vec, itemtrace, prior, Priorbetween, vone,
                     dat, sitems, Prior);
             } else {
                 _Estep(expected, r1vec, Prior, vone, dat, itemtrace);
@@ -977,6 +1294,12 @@ RcppExport SEXP computeInfo(SEXP Rpars, SEXP RTheta, SEXP RgPrior, SEXP Rprior,
                     item.slot("dat") = tmpmat;
                     pars[i] = item;
                 }
+//                 S4 item = pars[nitems];
+//                 for(int j = 0; j < J; ++j)
+//                     for(int i = 0; i < N; ++i)
+//                         r1(i,j) = r1(i,j) * Prior[i];
+//                 item.slot("dat") = r1;
+//                 pars[nitems] = item;
                 NumericMatrix hess(npars, npars);
                 vector<double> grad(npars);
                 _computeDpars(grad, hess, pars, Theta, offterm, nitems, npars, 0, 0);
